<?php

function get_events_for_display() {

    if(!wp_verify_nonce($_REQUEST['nonce'], "get_events_for_display_nonce")) {
		exit('Move along, nothing to see here.');
	}

    $date_filter = $_REQUEST['dateFilter'] ?? null;
    $date_picker = $_REQUEST['dateRange'] ?? null;

    $event_listings = array();
    $date_query = [];

    $event_query = array(
        'post_type' 		=> 'event',
        'posts_per_page' 	=> -1,
        'suppress_filters'  => false,
        'meta_query' 		=> array(
            'relation'  => 'AND',
            array(
                'key'       => 'event_status',
                'compare'   => '!=',
                'value'     => 'draft'
            ),
            array(
                'key'       => 'event_visibility',
                'compare'   => '=',
                'value'     => true
            ),
            array(
                'key'       => 'event_organiser',
                'compare'   => '=',
                'value'     => $_REQUEST['organiser'],
            ), 
        ),
    );

    if($date_filter && $date_filter != 'all') {

        if($date_filter == 'today') {

            $date_today = date("Y/m/d");
            $date_query = array(
                'key'		=> 'event_series_dates_$_event_series_start_datetime',
                'compare'	=> '=',
                'value'		=> $date_today,
                'type'      => 'DATE',
            );
        }
        if($date_filter == 'week' || $date_filter == 'month') {
        
            $date_range = rangeDate(date("Y/m/d"), $date_filter);
            $date_query = array(
                    'key'		=> 'event_series_dates_$_event_series_start_datetime',
                    'compare'	=> 'BETWEEN',
                    'value'		=> array($date_range['start'], $date_range['end']),
                    'type'      => 'DATE',
            );
        }

        array_push($event_query['meta_query'], $date_query);
        
    }
    if($date_picker) {

        $cleanedString = stripslashes($date_picker);
        $date_range = json_decode($cleanedString, true);
        $startTimeStamp = strtotime($date_range['start']);
        $endTimeStamp = strtotime($date_range['end']);
        $start = date("Y-m-d", $startTimeStamp);
        $end = date("Y-m-d", $endTimeStamp);

        $date_query = array(
            'key'		=> 'event_series_dates_$_event_series_start_datetime',
            'compare'	=> 'BETWEEN',
            'value'		=> array($start, $end),
            'type'      => 'DATE',
        );
        array_push($event_query['meta_query'], $date_query);
    }

    $events = get_posts($event_query);

    if($events) {

        foreach($events as $event) {
            $event_dates = get_field('event_series_dates', $event);
            if($event_dates) {
                
                $sorted_dates = array();
                foreach($event_dates as $event_date) {
                    
                    $start_date = $event_date['event_series_start_datetime'];
                    if(strtotime($start_date) >= strtotime("today")) {
                        $dateObject = new DateTime($start_date);
                        array_push($sorted_dates, $dateObject);
                    }
                    
                }

                if(count($sorted_dates) > 0) {
                    usort($sorted_dates, function ($a, $b) {
                        return $a->format('Y-m-d H:i:s') <=> $b->format('Y-m-d H:i:s');
                    });

                    $event_id = $event->ID;
                    $title = get_the_title($event_id);
                    $next_event_date = $sorted_dates[0]->format('Y-m-d H:i:s');
                    $next_date = date("D, jS M Y", strtotime($next_event_date));
                    $next_time = date("g:ia", strtotime($next_event_date));
                    $fields = get_fields($event_id);
                    $featured_image = isset($fields['featured_image']) ? $fields['featured_image'] : null;
                    $summary = $fields['event_summary'];
                    $series = $fields['is_event_series'];
                    $link = get_the_permalink($event_id);

                    $ev = array(
                        'event_id'  => $event_id,
                        'title'     => $title,
                        'next_date' => $next_date,
                        'next_time' => $next_time,
                        'image'     => $featured_image,
                        'summary'   => $summary,  
                        'is_series' => $series,
                        'link'      => $link,
                    );

                    array_push($event_listings, $ev);
                }

            }
        }

    }
    
    wp_send_json($event_listings);

}
add_action("wp_ajax_get_events_for_display", "get_events_for_display");
add_action("wp_ajax_nopriv_get_events_for_display", "get_events_for_display");


function rangeDate($datestr, $time_period) {

    date_default_timezone_set(date_default_timezone_get());
    $dt = strtotime($datestr);

    if($time_period == 'week') {
        return array (
            "start" => date ('N', $dt) == 1 ? date ('Y-m-d', $dt) : date ('Y-m-d', strtotime ('last monday', $dt)),
            "end" => date('N', $dt) == 7 ? date ('Y-m-d', $dt) : date ('Y-m-d', strtotime ('next sunday', $dt))
        );
    } elseif($time_period == 'month') {
        return array (
            "start" => date ('Y-m-d', strtotime ('first day of this month', $dt)),
            "end" => date ('Y-m-d', strtotime ('last day of this month', $dt))
        );
    }
    
}