<?php

require($_SERVER['DOCUMENT_ROOT'] . '/../vendor/autoload.php');
require($_SERVER['DOCUMENT_ROOT'] . '/wp/wp-load.php');

use HubSpot\Factory;
use HubSpot\Client\Crm\Contacts\Model\PublicObjectSearchRequest as ContactPublicObjectSearchRequest;
use HubSpot\Client\Crm\Contacts\Model\SimplePublicObjectInput as ContactSimplePublicObjectInput;
use HubSpot\Client\Crm\Contacts\Model\Filter as ContactFilter;
use HubSpot\Client\Crm\Contacts\Model\FilterGroup as ContactFilterGroup;
use HubSpot\Client\Crm\Contacts\ApiException as ContactApiException;
use HubSpot\Client\CommunicationPreferences\ApiException;
use HubSpot\Client\CommunicationPreferences\Model\PublicUpdateSubscriptionStatusRequest;

$client = Factory::createWithAccessToken($_ENV['HUBSPOT_API_KEY']);

// search hubspot for contact by ID
function hubspot_search_contacts($email) {

    global $client;

    $filter1 = new ContactFilter([
        'value'         => $email,
        'property_name' => 'email',
        'operator'      => 'EQ'
    ]);
    $filterGroup1 = new ContactFilterGroup([
        'filters' => [$filter1]
    ]);
    $publicObjectSearchRequest = new ContactPublicObjectSearchRequest([
        'filter_groups' => [$filterGroup1], 
    ]);
    try {
        $apiResponse = $client->crm()->contacts()->searchApi()->doSearch($publicObjectSearchRequest);
        return json_decode($apiResponse, true);
        
    } catch (ContactApiException $e) {
        return json_decode($e->getMessage(), true);
    }

}


// create a hubspot contact
function hubspot_create_contact($contact_data) {

    global $client;
    $response = null;

    // search for existing contacts
    $hs_contact = hubspot_search_contacts($contact_data['email']);
    if($hs_contact['total'] === 0) {

        $simplePublicObjectInput = new ContactSimplePublicObjectInput([
            'properties' => $contact_data,
        ]);
        try {
            $apiResponse = $client->crm()->contacts()->basicApi()->create($simplePublicObjectInput);
            $new_hs_contact = json_decode($apiResponse, true);
            $response = $new_hs_contact['id'];
    
        } catch (ContactApiException $e) {
            $response = $e->getMessage();
        }

    } else {
        $hs_contact_id = $hs_contact['results'][0]['id'];
        $response = hubspot_update_contact($hs_contact_id, $contact_data);
    }

    return $response;
    
}


// update a hubspot contact
function hubspot_update_contact($contact_id, $contact_data) {

    global $client;
    $simplePublicObjectInput = new ContactSimplePublicObjectInput([
        'properties' => $contact_data,
    ]);
    try {
        $apiResponse = $client->crm()->contacts()->basicApi()->update($contact_id, $simplePublicObjectInput);
        return json_decode($apiResponse, true);

    } catch (ContactApiException$e) {
        echo "Exception when calling basic_api->update: ", $e->getMessage();
    }
}


// add a contact to hubspot subscription type
function hubspot_add_contact_to_subscription_type($email, $subtype) {

    global $client;
    $publicUpdateSubscriptionStatusRequest = new PublicUpdateSubscriptionStatusRequest([
        'email_address'             => $email,
        'subscription_id'           => $subtype,
        'legal_basis'               => 'CONSENT_WITH_NOTICE',
        'legal_basis_explanation'   => 'Opted in at users request',
    ]);
    try {
        $apiResponse = $client->communicationPreferences()->statusApi()->subscribe($publicUpdateSubscriptionStatusRequest);
        return json_decode($apiResponse, true);

    } catch (ApiException $e) {
        return "Exception when calling status_api->subscribe: " . $e->getMessage();
    }
    
}